[![PyPI version](https://badge.fury.io/py/tohu.svg)](https://badge.fury.io/py/tohu) [![CircleCI](https://circleci.com/gh/maxalbert/tohu.svg?style=shield)](https://circleci.com/gh/maxalbert/tohu)

<img src="./docs/img/logo.png" alt="Tohu Logo" width="70px">

tohu: Your friendly synthetic data generator
============================================

Overview
--------

TODO


Get it now
----------

```bash
$ pip install tohu
```


Documentation
-------------

Full documentation is available at https://maxalbert.github.io/tohu/


Requirements
------------

- Python >= 3.6

Tohu requires Python 3.6 or greater. There is no intention to support earlier versions.


License
-------

See [LICENSE](./LICENSE)


Attributions
------------

- The tohu logo is ["Chaos"](https://thenounproject.com/madeirah/uploads/?i=1893477), created by [Anna Sophie](https://thenounproject.com/madeirah/) from the [Noun Project](https://thenounproject.com/) (licensed under [CC BY 3.0](https://creativecommons.org/licenses/by/3.0/legalcode))